@@ -1,10 +1,15 @@
 import sys
+import yaml
 
 import django
-from djangoldp.tests import settings_default
-from django.conf import settings
+from django.conf import settings as django_settings
+from djangoldp.conf.ldpsettings import LDPSettings
+from djangoldp.tests.settings_default import yaml_config
 
-settings.configure(default_settings=settings_default)
+# load test config
+config = yaml.safe_load(yaml_config)
+ldpsettings = LDPSettings(config)
+django_settings.configure(ldpsettings)
 
 django.setup()
 from django.test.runner import DiscoverRunner
@@ -12,6 +17,7 @@ from django.test.runner import DiscoverRunner
 test_runner = DiscoverRunner(verbosity=1)
 
 failures = test_runner.run_tests([
+    'djangoldp.tests.tests_settings',
     'djangoldp.tests.tests_ldp_model',
     'djangoldp.tests.tests_ldp_viewset',
     'djangoldp.tests.tests_save',
